/*
 * Copyright (c) 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <syscall.h>
#include <errno.h>
#include <sys/types.h>

#include "xfs_message.h"
#include "xfs_syscalls.h"

RCSID("$Id: setdebug.c,v 1.7 1998/07/24 01:18:22 map Exp $");

static
_syscall5(int, afs_syscall,
	  int, operation,
	  char *, a_pathP,
	  int, a_opcode,
	  struct ViceIoctl *, a_paramsP,
	  int, a_followSymlinks)
void
usage(void)
{
    printf("usage: setdebug <on|off>\n");
    exit(1);
}

int main(int argc, char **argv)
{
    int retval;

    if (argc != 2)
	usage();

    if (strcmp(argv[1], "on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "off") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_CLEAR_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "vnops-on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_VNOPS_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "vfops-on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_VFOPS_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "msg-on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_MSG_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "node-on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_NODE_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "readdir-off") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_CLEAR_READDIR_DEBUG, NULL, 0);
    } else if (strcmp(argv[1], "lock-on") == 0) {
	retval = afs_syscall(AFSCALL_XFS, NULL, XFSSYSCALL_SET_LOCK_DEBUG, NULL, 0);
    } else {
	usage();
    }
}

